<?php

namespace Moblyze\Competency\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Competency\Http\Requests\CompetencyRequest;
use Moblyze\Competency\Interfaces\CompetencyRepositoryInterface;
use Moblyze\Competency\Models\Competency;
use Moblyze\Competency\Forms\Competency as Form;

/**
 * APIController  class for competency.
 */
class CompetencyAPIController extends BaseController
{

    /**
     * Initialize competency resource controller.
     *
     * @param type CompetencyRepositoryInterface $competency
     *
     * @return null
     */
    public function __construct(CompetencyRepositoryInterface $competency)
    {
        parent::__construct();
        $this->repository = $competency;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Competency\Repositories\Criteria\CompetencyResourceCriteria::class);
    }

    /**
     * Display a list of competency.
     *
     * @return Response
     */
    public function index(CompetencyRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Competency\Repositories\Presenter\CompetencyPresenter::class)
            ->paginate();
    }

    /**
     * Display competency.
     *
     * @param Request $request
     * @param Model   $competency
     *
     * @return Response
     */
    public function show(CompetencyRequest $request, Competency $competency)
    {
        return $competency->setPresenter(\Moblyze\Competency\Repositories\Presenter\CompetencyListPresenter::class);
        ;
    }

    /**
     * Create new competency.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CompetencyRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('competency::competency.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('competency/competency/' . $competency->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('competency/competency');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the competency.
     *
     * @param Request $request
     * @param Model   $competency
     *
     * @return Response
     */
    public function update(CompetencyRequest $request, Competency $competency)
    {
        try {
            $data = $request->all();

            $competency->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('competency::competency.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('competency/competency/' . $competency->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('competency/competency/' . $competency->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the competency.
     *
     * @param Model   $competency
     *
     * @return Response
     */
    public function destroy(CompetencyRequest $request, Competency $competency)
    {
        try {
            $competency->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('competency::competency.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('competency/competency/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('competency/competency/' . $competency->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
