<?php

namespace Moblyze\Competency\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Moblyze\Competency\Interfaces\CourseRepositoryInterface;

class CoursePublicController extends BaseController
{
    // use CourseWorkflow;

    /**
     * Constructor.
     *
     * @param type \Moblyze\Course\Interfaces\CourseRepositoryInterface $course
     *
     * @return type
     */
    public function __construct(CourseRepositoryInterface $course)
    {
        $this->repository = $course;
        parent::__construct();
    }

    /**
     * Show course's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $courses = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('competency::course.names'))
            ->view('competency::public.course.index')
            ->data(compact('courses'))
            ->output();
    }


    /**
     * Show course.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $course = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($course->name . trans('competency::course.name'))
            ->view('competency::public.course.show')
            ->data(compact('course'))
            ->output();
    }

}
