<?php

namespace Moblyze\Competency\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Competency\Models\Competency;

class CompetencyPolicy
{

    /**
     * Determine if the given user can view the competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function view(UserPolicy $user, Competency $competency)
    {
        if ($user->canDo('competency.competency.view') && $user->isAdmin()) {
            return true;
        }

        return $competency->user_id == user_id() && $competency->user_type == user_type();
    }

    /**
     * Determine if the given user can create a competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('competency.competency.create');
    }

    /**
     * Determine if the given user can update the given competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function update(UserPolicy $user, Competency $competency)
    {
        if ($user->canDo('competency.competency.edit') && $user->isAdmin()) {
            return true;
        }

        return $competency->user_id == user_id() && $competency->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Competency $competency)
    {
        return $competency->user_id == user_id() && $competency->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Competency $competency)
    {
        if ($user->canDo('competency.competency.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given competency.
     *
     * @param UserPolicy $user
     * @param Competency $competency
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Competency $competency)
    {
        if ($user->canDo('competency.competency.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
