<?php

namespace Moblyze\Competency\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Competency\Models\Crewtype;

class CrewtypePolicy
{

    /**
     * Determine if the given user can view the crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Crewtype $crewtype)
    {
        if ($user->canDo('competency.crewtype.view') && $user->isAdmin()) {
            return true;
        }

        return $crewtype->user_id == user_id() && $crewtype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('competency.crewtype.create');
    }

    /**
     * Determine if the given user can update the given crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Crewtype $crewtype)
    {
        if ($user->canDo('competency.crewtype.edit') && $user->isAdmin()) {
            return true;
        }

        return $crewtype->user_id == user_id() && $crewtype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Crewtype $crewtype)
    {
        return $crewtype->user_id == user_id() && $crewtype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Crewtype $crewtype)
    {
        if ($user->canDo('competency.crewtype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given crewtype.
     *
     * @param UserPolicy $user
     * @param Crewtype $crewtype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Crewtype $crewtype)
    {
        if ($user->canDo('competency.crewtype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
