<?php

namespace Moblyze\Competency\Providers;

use Illuminate\Support\ServiceProvider;

class CompetencyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'competency');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'competency');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCompetency();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCompetency()
    {
        $this->app->bind('competency', function($app) {
            return new Competency($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Competency', 'Lavalite\Competency\Facades\Competency');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('moblyze.competency', function ($app) {
            return $this->app->make('Moblyze\Competency\Competency');
        });

        // Bind Course to repository
        $this->app->bind(
            'Moblyze\Competency\Interfaces\CourseRepositoryInterface',
            \Moblyze\Competency\Repositories\Eloquent\CourseRepository::class
        );
        // Bind Competency to repository
        $this->app->bind(
            'Moblyze\Competency\Interfaces\CompetencyRepositoryInterface',
            \Moblyze\Competency\Repositories\Eloquent\CompetencyRepository::class
        );
        // Bind User to repository
        $this->app->bind(
            'Moblyze\Competency\Interfaces\UserRepositoryInterface',
            \Moblyze\Competency\Repositories\Eloquent\UserRepository::class
        );
        // Bind Crewtype to repository
        $this->app->bind(
            'Moblyze\Competency\Interfaces\CrewtypeRepositoryInterface',
            \Moblyze\Competency\Repositories\Eloquent\CrewtypeRepository::class
        );

        $this->app->register(\Moblyze\Competency\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Moblyze\Competency\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and competency's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'moblyze.competency'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCompetency::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['moblyze.competency'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('moblyze/competency.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/competency')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/competency')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
