<?php

namespace Moblyze\Competency\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Moblyze\Competency\Models\Competency;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Moblyze\Competency\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/competency/course/*')) {
            Route::bind('course', function ($course) {
                $courserepo = $this->app->make('Moblyze\Competency\Interfaces\CourseRepositoryInterface');
                return $courserepo->findorNew($course);
            });
        }

        if (Request::is('*/competency/competency/*')) {
            Route::bind('competency', function ($competency) {
                $competencyrepo = $this->app->make('Moblyze\Competency\Interfaces\CompetencyRepositoryInterface');
                return $competencyrepo->findorNew($competency);
            });
        }

        if (Request::is('*/competency/user/*')) {
            Route::bind('user', function ($user) {
                $userrepo = $this->app->make('Moblyze\Competency\Interfaces\UserRepositoryInterface');
                return $userrepo->findorNew($user);
            });
        }

        if (Request::is('*/competency/crewtype/*')) {
            Route::bind('crewtype', function ($crewtype) {
                $crewtyperepo = $this->app->make('Moblyze\Competency\Interfaces\CrewtypeRepositoryInterface');
                return $crewtyperepo->findorNew($crewtype);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
